.. _api_pixel_utils:

Pixel Data Utilities (:mod:`pydicom.pixels.utils`)
==================================================

.. module:: pydicom.pixels.utils
.. currentmodule:: pydicom.pixels.utils

Pixel data related utility functions.

.. autosummary::
   :toctree: generated/

   as_pixel_options
   compress
   decompress
   expand_ybr422
   get_expected_length
   get_image_pixel_ids
   get_j2k_parameters
   get_nr_frames
   iter_pixels
   pack_bits
   pixel_array
   pixel_dtype
   reshape_pixel_array
   set_pixel_data
   unpack_bits
